@@ -94,23 +94,8 @@ def process_args(
         if args.dry_run:
             continue
 
-        toc_file = toctree(
-            current.path_list,
-            new_subdirs,
-            current.files,
-            maxtocdepth,
-            root_path,
-            dir_display_name_converter=dir_display_name_converter,
-        )
-        # Check to see if we are at the last item to be processed
-        # (which has already been popped)
-        # to write the asked for master TOC file name.
-        if not work_to_do:
-            toc_filename = top_level_toc_filename
-        else:
-            toc_filename = output_path / make_flat_name(current.path_list, is_dir=True)
-        toc_file.write_to_file(toc_filename)
-
+        # Make a copy of the list, as some items may be removed.
+        files_for_toc = list(current.files)
         for a_file in current.files:
             a_file_list = current.path_list + [a_file]
             source_name = pathlib.Path().joinpath(*a_file_list)
@@ -126,7 +111,13 @@ def process_args(
                     integrate_background=args.integrate_background,
                     background_step_format=args.background_step_format,
                     raw_descriptions=args.raw_descriptions,
+                    include_tags=args.include_tags,
+                    exclude_tags=args.exclude_tags,
                 )
+                if not feature_rst_file:
+                    files_for_toc.remove(a_file)
+                    continue
+
                 verbose(f'converting "{source_name}" to "{dest_name}"')
                 feature_rst_file.write_to_file(dest_name)
             elif not is_rst_file(a_file):
@@ -136,6 +127,23 @@ def process_args(
                 verbose(f'copying "{source_name}" to "{dest_name}"')
                 shutil.copy(source_path, dest_name)
 
+        toc_file = toctree(
+            current.path_list,
+            new_subdirs,
+            files_for_toc,
+            maxtocdepth,
+            root_path,
+            dir_display_name_converter=dir_display_name_converter,
+        )
+        # Check to see if we are at the last item to be processed
+        # (which has already been popped)
+        # to write the asked for master TOC file name.
+        if not work_to_do:
+            toc_filename = top_level_toc_filename
+        else:
+            toc_filename = output_path / make_flat_name(current.path_list, is_dir=True)
+        toc_file.write_to_file(toc_filename)
+
     if step_glossary_name:
         glossary_filename = output_path / f"{step_glossary_name}.rst"
         glossary = make_steps_glossary(doc_project)
@@ -222,7 +230,7 @@ def main() -> None:
         "--parser",
         default="behave",
         choices=list(parsers.keys()),
-        help=f"Specify an alternate parser to use.",
+        help="Specify an alternate parser to use.",
     )
     parser.add_argument(
         "-v",
@@ -262,6 +270,20 @@ def main() -> None:
             "This allows descriptions to contain rST links, code blocks, etc."
         ),
     )
+    include_exclude_tags_caveat = (
+        "If a feature/scenario has both an exclude and and include tag,"
+        "it will be excluded."
+    )
+    exclude_tags_help = (
+        "Features and scenarios tagged with these exclude tags "
+        "will not be included in the build docs. " + include_exclude_tags_caveat
+    )
+    parser.add_argument("--exclude-tags", help=exclude_tags_help, nargs="*")
+    include_tags_help = (
+        "Only features and scenarios tagged with at least one of these include tags "
+        "will be included in the build docs." + include_exclude_tags_caveat
+    )
+    parser.add_argument("--include-tags", help=include_tags_help, nargs="*")
 
     args = parser.parse_args()
 
