@@ -10,9 +10,7 @@ import behave.model_core
 
 from .files import is_rst_file
 from .glossary import step_glossary
-from .parsers import behave as behave_models
-from .parsers import parsers
-from .parsers import pytest_bdd as pytest_bdd_models
+from .parsers import parsers, ClassWithExamples
 from .utils import (
     display_name,
     make_flat_name,
@@ -20,6 +18,7 @@ from .utils import (
     rst_escape,
     SphinxWriter,
     verbose,
+    get_all_included_scenarios,
 )
 
 _keywords = (
@@ -154,7 +153,9 @@ def feature_to_rst(
     integrate_background: bool = False,
     background_step_format: str = "{}",
     raw_descriptions: bool = False,
-) -> SphinxWriter:
+    include_tags: List[str] = None,
+    exclude_tags: List[str] = None,
+) -> Optional[SphinxWriter]:
     """Return a SphinxWriter containing the rST for the given feature file."""
     output_file = SphinxWriter()
 
@@ -317,18 +318,14 @@ def feature_to_rst(
                 text(step.text)
 
     def examples(
-        example_source: Union[
-            behave_models.Scenario,
-            pytest_bdd_models.Scenario,
-            pytest_bdd_models.Feature,
-        ],
+        example_source: ClassWithExamples,
         example_source_parent: Optional[behave.model.Feature] = None,
     ) -> None:
         tag_sources = [example_source]
         if example_source_parent:
             tag_sources.append(example_source_parent)
         for example in getattr(example_source, "examples", []):
-            if isinstance(example_source, pytest_bdd_models.Feature):
+            if example_source.__class__.__name__ == "Feature":
                 # Set feature examples tables at the same section level as scenarios.
                 section_level = 2
             else:
@@ -365,6 +362,15 @@ def feature_to_rst(
             f" options are: {list(parsers.keys())}"
         )
     feature = feature_class(root_path, source_path)
+
+    included_scenarios = get_all_included_scenarios(feature, include_tags, exclude_tags)
+    # In the event of a feature existing,
+    # but not having scenarios in it,
+    # only exclude the feature (and its description, etc)
+    # if include/exclude logic has been activated.
+    if not included_scenarios and (include_tags or exclude_tags):
+        return None
+
     section(1, feature)
     description(feature, raw_descriptions=raw_descriptions)
     if feature.examples:
@@ -373,7 +379,7 @@ def feature_to_rst(
         section(2, feature.background)
         steps(feature.background.steps)
         output_file.blank_line()
-    for scenario in feature.scenarios:
+    for scenario in included_scenarios:
         section(2, scenario)
         tags(scenario.tags, feature)
         description(scenario, raw_descriptions=raw_descriptions)
